@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003-2020 Free Software Foundation, Inc.
+   Copyright (C) 2003-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -119,6 +119,11 @@ auth_gsasl (struct imap4d_auth *ap)
 	  ap->response = RESP_NO;
 	  return imap4d_auth_resp;
 	}
+      if (!stream[1])
+	{
+	  mu_stream_ref(stream[1] = stream[0]);
+	}
+      
       rc = gsasl_encoder_stream (&newstream[0], stream[0], sess_ctx,
 				 MU_STREAM_READ);
       if (rc)
@@ -156,7 +161,7 @@ auth_gsasl (struct imap4d_auth *ap)
 
       mu_stream_unref (stream[0]);
       mu_stream_unref (stream[1]);
-      
+
       rc = mu_stream_ioctl (iostream, MU_IOCTL_SUBSTREAM, 
                             MU_IOCTL_OP_SET, newstream);
       if (rc)
