@@ -1,5 +1,5 @@
 /* stdcapa.c -- Standard CLI capabilities for GNU Mailutils
-   Copyright (C) 2016-2024 Free Software Foundation, Inc.
+   Copyright (C) 2016-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -18,6 +18,7 @@
 # include <config.h>
 #endif
 #include <stdlib.h>
+#include <unistd.h>
 #include <mailutils/cli.h>
 #include <mailutils/cfg.h>
 #include <mailutils/nls.h>
@@ -667,6 +668,61 @@ mu_auth_section_parser
   return 0;
 }
 
+static int
+cb_file_mode (void *data, mu_config_value_t *val)
+{
+  char *p;
+  int n;
+  if (mu_cfg_assert_value_type (val, MU_CFG_STRING))
+    return 1;
+  n = strtoul (val->v.string, &p, 8);
+  if (p[0] || (n & ~0777))
+    mu_error (_("invalid mode specification: %s"), val->v.string);
+  *(int*) data = n;
+  return 0;
+}
+
+int mu_homedir_create;
+int mu_homedir_mode = 0755;
+
+int
+mu_homedir_assert (char const *dir, uid_t uid, gid_t gid)
+{
+  int rc;
+
+  if (!dir)
+    rc = EINVAL;
+  else if (mu_homedir_create)
+    {
+      int u = umask (0);
+      if ((rc = mu_mkinterdir (dir, mu_homedir_mode, 0755)) == 0)
+	{
+	  if (chown (dir, uid, gid))
+	    rc = errno;
+	}
+      umask (u);
+    }
+  else
+    {
+      struct stat st;
+      if (stat (dir, &st) == 0)
+	rc = S_ISDIR (st.st_mode) ? 0 : ENOTDIR;
+      else
+	rc = errno;
+    }
+  return rc;
+}
+
+static struct mu_cfg_param mu_homedir_param[] = {
+  { "create", mu_c_bool, &mu_homedir_create, 0, NULL,
+    N_("Create user home directory if it doesn't exist."),
+    N_("arg") },
+  { "mode", mu_cfg_callback, &mu_homedir_mode, 0, cb_file_mode,
+    N_("File mode for creating user home directories."),
+    N_("mode: octal") },
+  { NULL }
+};
+
 /* ************************************************************************* *
  * Registry of standard mailutils' capabilities                              *
  * ************************************************************************* */
@@ -679,7 +735,7 @@ struct mu_cli_capa mu_cli_std_capa[] = {
   { "locking", NULL, locking_cfg, NULL, NULL },
   { "address", NULL, address_cfg, NULL, NULL },
   { "auth",    NULL, mu_auth_param, mu_auth_section_parser },
-
+  { "homedir", NULL, mu_homedir_param, NULL },
   { NULL }
 };
 
